@@ -1,5 +1,7 @@
 # vim: set expandtab ts=4 sw=4 filetype=python:
 
+from __future__ import with_statement
+
 import contextlib, multiprocessing, os, subprocess, sys, time, warnings
 from UserDict import UserDict
 from copy import copy
@@ -217,3 +219,21 @@ def maybe_add_ellipses(s, maxlen=72):
 
     else:
         return "%s..." % s[:maxlen]
+
+
+def edit_with_editor(s=None):
+    """
+    Open os.environ['EDITOR'] and load in text s.
+    
+    Returns the text typed in the editor.
+    """
+
+    # This is the first time I've used with!
+    with tempfile.NamedTemporaryFile() as t:
+
+        if s:
+            t.write(s)
+            t.seek(0)
+
+        subprocess.call([os.environ.get('EDITOR', 'vi'), t.name])
+        return t.read()
